*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* PAPER: Compliance Behavior in Networks: Evidence from a Field Experiment
* AUTHORS: Francesco Drago, Friederike Mengel, & Christian Traxler
* JOURNAL: AEJ: Applied Econ
*
* Replication File #1 (Main Tables + Figures, except Tab 4 + Tab B1)
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

clear all
version 13
set more off

* !!! ADJUST YOUR DIRECTORY HERE !!!
global folder "C:\DATA\networks\"
cd    "$folder"

cap clear
use "Networks_50.dta", clear
cap mkdir OUTPUT
cd   "$folder\OUTPUT"

cap log close
log using "replication_part01.log",replace

* ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* T A B L E S      ( + descriptives mentioned in Section III)
* ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

*TYPE I HHs
count if field_all1==1

tab field_nomail1
tab field_base1
tab field_threat1

*TYPE II HHs
count if field_all1==0 & (comp_exante==0)

*TYPE III HHs
count if field_all1==0 & (comp_exante==1)

* => types in relevant networks are defined below

*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

*********
* TABLE 1
*********

global vars  compliance  comp_exante gender age  degree EV_centr

foreach Y in nomail base threat {
 su $vars if field_`Y'1==1
}

*su $vars if field_all1==0 & (comp_exante==0)


*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

*********
* TABLE B1 (for Z = 50) + Numbers mentioned in text (Section III)
*********

gen type=.
label var type "types (in relevant networks only)"

*** Type II Houeholds : conditions (1) NOT part of field experiment, (2) initially non-compliant, (3) in a network with at least one experimental (type I) households
replace type=2 if field_all1==0 & comp_exante==0 & m_all1>0

* Temporary indicator: networks w at least one type II households
bysort net50_ID: egen type2_in=max(type)

*** Type I HHs
replace type=1 if field_all1==1                  & m_all1>0 & type2_in==2

*** Type III
replace type=3 if field_all1~=1  & comp_exante==1 & m_all1>0 & type2_in==2

tab type


*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

* Indicator for relevant_networks
gen      relevant_network=0
replace  relevant_network=1 if type2_in==2 & m_all1>0
drop type2_in

*number of municipalities
egen municipality_temp = group(municip) if relevant_network==1
su   municipality_temp
drop municipality_temp


*********
* TABLE 2 -- Panel A
*********

global sumstat_varsA degree fon fon_1 fon_2 fon_0 son son_1 son_2 son_0 dist dist1 dist2 dist0 compliance

su $sumstat_varsA if type==2
centile $sumstat_varsA if type==2, c(50 25 75)


*********
* TABLE 2 -- Panel B
*********
preserve

*keep if relevant_network==1 & field_all1==0 & comp_exante==0
keep if type==2

gen     Control_temp=0
replace Control_temp=1 if m_nomailup>0

global sumstat_varsB  m_allup m_baseup m_threatup m_nomailup Control_temp

sort net50_ID ID

gen     unique_temp=1
replace unique_temp=0 if net50_ID==net50_ID[_n-1]
*tab unique_t if sample_net

* collapse , by(net50_ID)

su $sumstat_varsB   if unique_t ==1

*number mentioned in text: networks with at least one type I HH in control group
count if Control_temp==1 & unique_t==1
drop Control_temp

restore

*********
* TABLE 2 -- Panel C
*********
preserve

keep if type==2

gen nat_nonA=1-nat_A

collapse   pop2005 income  age_municip rel_kath nat_nonA    turnout home , by(municip)

su      pop2005 income  age_municip rel_kath nat_nonA    turnout home
centile pop2005 income  age_municip rel_kath nat_nonA    turnout home, c(50 25 75)

restore

*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*********
* Prepares Variables for Table 3
*********

bysort municip: egen municip_N=count(_N)
***FIELD EXPERIMENT
*frequency of baseline mailings (from field experiment) sent to others in "municipality - network"
bysort municip: egen m_basegcode=sum(field_base1)
replace m_basegcode=m_basegcode-1 if field_base1==1
replace m_basegcode=m_basegcode/(municip_N-1)

*frequency of threat mailings (from field experiment) sent to others in "municipality - network"
bysort municip: egen m_threatgcode=sum(field_threat1)
replace m_threatgcode=m_threatgcode-1 if field_threat1==1
replace m_threatgcode=m_threatgcode/(municip_N-1)

*frequency of no_mailing treatments (field experiment) among others in "municipality - network"
bysort municip: egen m_nomailgcode=sum(field_nomail1)
replace m_nomailgcode=m_nomailgcode-1 if field_nomail1==1
replace m_nomailgcode=m_nomailgcode/(municip_N-1)

*frequency of HHs treated by field experiment among others in "municipality - network"
bysort municip: egen m_allgcode=sum(field_all1)
replace m_allgcode=m_allgcode-1 if field_all1==1
replace m_allgcode=m_allgcode/(municip_N-1)


***************
*TABLE 3 - estimates/output
***************

*column 1***
areg compliance   m_baseup m_threatup  m_allup if type==2, a(m_allup) cluster(net50_ID)
 test m_baseup=m_threatup
  outreg2  using "Table_3.tex", tex(frag) nocons  adds(Networks, e(N_clust), F-Stat, r(F)) sdec(4) bdec(4) replace

*column 2***
reg compliance  m_baseup m_threatup  m_allup if type==2 , cluster(net50_ID)
 test m_baseup=m_threatup
  outreg2  using "Table_3.tex", tex(frag) adds(Networks, e(N_clust), F-Stat, r(F)) sdec(4) bdec(4) append

*column 3 (estimated for the type2 hhs from other specifications)
reg compliance    m_allgcode m_basegcode m_threatgcode  if type==2  , cluster(municip)
 test m_basegcode=m_threatgcode
  outreg2  using "Table_3.tex", tex(frag) adds(Networks, e(N_clust), F-Stat, r(F)) sdec(4) bdec(4) append

*column 4
dprobit compliance m_allup m_baseup m_threatup  if type==2 , cluster(net50_ID)
 test m_baseup=m_threatup
  outreg2  using "Table_3.tex", tex(frag) adds(Networks, e(N_clust), F-Stat, r(chi2)) sdec(4) bdec(4) append

*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*column 5

preserve

keep if e(sample)
set matsize 900

qui tab m_allup, gen(idm_allup)
*qui tab municip, gen (idgcode)
areg compliance m_baseup m_threatup idm_allup* if type==2  , a(municip) cluster(net50_ID)
 test m_baseup=m_threatup
  outreg2  using "Table_3.tex", tex(frag) nocons adds(Networks, e(N_clust), F-Stat, r(F)) sdec(4) bdec(4) keep(m_baseup m_threatup) append
drop idm_allup*

restore

*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*column 6

bysort net50_ID: egen detection_rate=mean(detection_pre)

areg compliance m_baseup m_threatup  detection_rate   if type==2 , a(m_allup) cluster(net50_ID)
 test m_baseup=m_threatup
  outreg2   using "Table_3.tex", tex(frag) nocons adds(Networks, e(N_clust), F-Stat, r(F)) sdec(4) bdec(4) append

*column 7 (detection_rate==0 assures that there was no-one detected in these networks)
areg compliance m_baseup m_threatup   if type==2  & detection_rate==0,   a(m_allup) cluster(net50_ID)
 test m_baseup=m_threatup
  outreg2   using "Table_3.tex", tex(frag) nocons adds(Networks, e(N_clust), F-Stat, r(F)) sdec(4) bdec(4) append

*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


*********
* TABLE B3  - interactions with municipality variables
*********

cap gen nat_nonA=1-nat_A

foreach var in income  rel_kath pop2005 age_municip nat_nonA turnout home  {
 gen m_allupX`var'=m_allup*`var'
}

foreach var in income  rel_kath pop2005 age_municip nat_nonA turnout home  {
 gen m_baseupX`var'=m_baseup*`var'
}

foreach var in income  rel_kath pop2005 age_municip nat_nonA turnout home  {
 gen m_threatupX`var'=m_threatup*`var'
}

foreach var in income  rel_kath pop2005 age_municip nat_nonA turnout home  {
areg compliance  m_baseup m_threatup m_baseupX`var' m_threatupX`var' `var'   if type==2, a(m_allup) cluster(net50_ID)
 outreg2 m_allup m_baseup m_threatup  m_threatupX`var'  m_baseupX`var' m_threatup*`var' using "Table_B3.tex", tex(frag)   dec(4) addstat(Networks, e(N_clust)) title (Heterogeneous effects) bdec(4) nocons
}

*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

*********
* TABLE 4
*********

* => see separate do file (#2)

*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


*********
*TABLE B4
*********
reg compliance  field_base1 field_threat1                        if field_all1==1 , r
 qui outreg2  using "Table_B4.tex", tex(frag)   sdec(4) bdec(4) replace

areg compliance  m_baseup m_threatup   field_base1 field_threat1 if field_all1==1  , a(m_allup) cluster(net50_ID)
 qui outreg2  using "Table_B4.tex", tex(frag) nocons sdec(4) bdec(4) append

reg compliance  field_base1 field_threat1                        if field_all1==1 & relevant_network==1, r
 qui outreg2  using "Table_B4.tex", tex(frag)   sdec(4) bdec(4) append

areg compliance  m_baseup m_threatup  field_base1 field_threat1  if field_all1==1 & relevant_network==1 , a(m_allup) cluster(net50_ID)
 outreg2  using "Table_B4.tex", tex(frag) nocons sdec(4) bdec(4) append


*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

*********
*TABLE B5
*********


*mean compliance among experimental households
bysort net50_ID: egen comp_r1=mean(comp_exante) if field_all1==1
*define last var for all types in network:
bysort net50_ID: egen comp_rate_type1=mean(comp_r1)


gen interbasecomp=m_baseup*comp_rate_type1
gen interallcomp=m_allup*comp_rate_type1
gen interthreatcomp=m_threatup*comp_rate_type1

areg compliance  m_baseup m_threatup   if type==2 & comp_rate_type1==1, a(m_allup) cluster(net50_ID)
 outreg2  using "Table_B5.tex", tex(frag) adds(Networks, e(N_clust)) nocons sdec(4) bdec(4) replace

areg compliance  m_baseup m_threatup   if type==2 & comp_rate_type1<1 , a(m_allup) cluster(net50_ID)
 outreg2  using "Table_B5.tex", tex(frag) adds(Networks, e(N_clust)) nocons sdec(4) bdec(4) append

areg compliance  m_baseup m_threatup   comp_rate_type1  interbasecomp interthreatcomp  if type==2, a(m_allup) cluster(net50_ID)
 outreg2  using "Table_B5.tex", tex(frag) adds(Networks, e(N_clust))  nocons sdec(4) bdec(4) append


*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


*********
* TABLE 5
*********

gen dist1_missing=0
gen dist2_missing=0
replace dist1_missing=1 if dist1==.
replace dist2_missing=1 if dist2==.

replace dist1=0 if dist1==.
replace dist2=0 if dist2==.

local append replace
local first 1
*Total-k Fixed Effects
areg compliance    m_baseup_fon m_baseup_son m_baseup_hon m_threatup_fon m_threatup_son m_threatup_hon    if type==2 , absorb(m_allup) cluster(net50_ID)
qui test m_baseup_fon=m_baseup_son
 scalar F12 = r(F)
 scalar p12 = r(p)
qui test m_baseup_fon=m_baseup_hon
 scalar F13 = r(F)
 scalar p13 = r(p)
qui test m_baseup_son=m_baseup_hon
 scalar F23 = r(F)
 scalar p23 = r(p)
qui test m_threatup_fon=m_threatup_son
 scalar t_F12 = r(F)
 scalar t_p12 = r(p)
qui test m_threatup_fon=m_threatup_hon
 scalar t_F13 = r(F)
 scalar t_p13 = r(p)
qui test m_threatup_son=m_threatup_hon
 scalar t_F23 = r(F)
 scalar t_p23 = r(p)
outreg2 using "Table_5_FonSon.tex", tex(frag) dec(4) addstat(Base 1-2 F, F12, Base 1-2 p, p12,    Base 1-3 F, F13, Base 1-3 p, p13,    Base 2-3 F, F23, Base 2-3 p, p23,    Threat 1-2 F, t_F12, Threat 1-2 p, t_p12,    Threat 1-3 F, t_F13, Threat 1-3 p, t_p13,    Threat 2-3 F, t_F23, Threat 2-3 p, t_p23) nocons  replace

areg compliance    m_baseup_fon m_baseup_son m_baseup_hon m_threatup_fon m_threatup_son m_threatup_hon dist1 dist2 dist1_missing dist2_missing if  type==2 , absorb(m_allup) cluster(net50_ID)
qui test m_baseup_fon=m_baseup_son
 scalar F12 = r(F)
 scalar p12 = r(p)
qui test m_baseup_fon=m_baseup_hon
 scalar F13 = r(F)
 scalar p13 = r(p)
qui test m_baseup_son=m_baseup_hon
 scalar F23 = r(F)
 scalar p23 = r(p)
qui test m_threatup_fon=m_threatup_son
 scalar t_F12 = r(F)
 scalar t_p12 = r(p)
qui test m_threatup_fon=m_threatup_hon
 scalar t_F13 = r(F)
 scalar t_p13 = r(p)
qui test m_threatup_son=m_threatup_hon
 scalar t_F23 = r(F)
 scalar t_p23 = r(p)
outreg2 using "Table_5_FonSon.tex", tex(frag) dec(4) addstat(Base 1-2 F, F12, Base 1-2 p, p12,    Base 1-3 F, F13, Base 1-3 p, p13,    Base 2-3 F, F23, Base 2-3 p, p23,    Threat 1-2 F, t_F12, Threat 1-2 p, t_p12,    Threat 1-3 F, t_F13, Threat 1-3 p, t_p13,    Threat 2-3 F, t_F23, Threat 2-3 p, t_p23)  nocons  append


reg compliance    m_allup_fon m_allup_son m_allup_hon m_baseup_fon m_baseup_son m_baseup_hon m_threatup_fon m_threatup_son m_threatup_hon             if type==2, cluster(net50_ID)
  test m_baseup_fon + m_allup_fon =m_baseup_son + m_allup_son
 scalar F12 = r(F)
 scalar p12 = r(p)
 test m_baseup_fon + m_allup_fon =m_baseup_hon  + m_allup_hon
 scalar F13 = r(F)
 scalar p13 = r(p)
 test m_baseup_son + m_allup_son =m_baseup_hon +  m_allup_hon
 scalar F23 = r(F)
 scalar p23 = r(p)
  test m_threatup_fon + m_allup_fon =m_threatup_son + m_allup_son
 scalar t_F12 = r(F)
 scalar t_p12 = r(p)
  test m_threatup_fon+ m_allup_fon=m_threatup_hon  + m_allup_hon
 scalar t_F13 = r(F)
 scalar t_p13 = r(p)
  test m_threatup_son  + m_allup_son=m_threatup_hon  + m_allup_hon
 scalar t_F23 = r(F)
 scalar t_p23 = r(p)
outreg2 using "Table_5_FonSon.tex", tex(frag) dec(4) addstat(Base 1-2 F, F12, Base 1-2 p, p12,    Base 1-3 F, F13, Base 1-3 p, p13,    Base 2-3 F, F23, Base 2-3 p, p23,    Threat 1-2 F, t_F12, Threat 1-2 p, t_p12,    Threat 1-3 F, t_F13, Threat 1-3 p, t_p13,    Threat 2-3 F, t_F23, Threat 2-3 p, t_p23)    append

 reg compliance    m_allup_fon m_allup_son m_allup_hon m_baseup_fon m_baseup_son m_baseup_hon m_threatup_fon m_threatup_son m_threatup_hon     dist1 dist2 dist1_missing dist2_missing        if type==2, cluster(net50_ID)
  test m_baseup_fon + m_allup_fon =m_baseup_son + m_allup_son
 scalar F12 = r(F)
 scalar p12 = r(p)
 test m_baseup_fon + m_allup_fon =m_baseup_hon  + m_allup_hon
 scalar F13 = r(F)
 scalar p13 = r(p)
 test m_baseup_son + m_allup_son =m_baseup_hon +  m_allup_hon
 scalar F23 = r(F)
 scalar p23 = r(p)
  test m_threatup_fon + m_allup_fon =m_threatup_son + m_allup_son
 scalar t_F12 = r(F)
 scalar t_p12 = r(p)
  test m_threatup_fon+ m_allup_fon=m_threatup_hon  + m_allup_hon
 scalar t_F13 = r(F)
 scalar t_p13 = r(p)
  test m_threatup_son  + m_allup_son=m_threatup_hon  + m_allup_hon
 scalar t_F23 = r(F)
 scalar t_p23 = r(p)
outreg2 using "Table_5_FonSon.tex", tex(frag) dec(4) addstat(Base 1-2 F, F12, Base 1-2 p, p12,    Base 1-3 F, F13, Base 1-3 p, p13,    Base 2-3 F, F23, Base 2-3 p, p23,    Threat 1-2 F, t_F12, Threat 1-2 p, t_p12,    Threat 1-3 F, t_F13, Threat 1-3 p, t_p13,    Threat 2-3 F, t_F23, Threat 2-3 p, t_p23)   append

*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

* ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*** Preparing Data for Table 6 Estimatates
* ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

* ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* DEFINES CUTOFFS (MEDIAN CENTRALITY LEVELS)
qui sum DC_t1_p1_rel1 if type==1,d
 scalar p50_DC1_p1 = r(p50)
qui sum DC_t10_p1_rel1 if type==1, d
 scalar p50_DC10_p1 = r(p50)
qui sum EV_centr if type==1, d
 scalar p50_EV = r(p50)
qui sum DC_norm if type==1, d
 scalar p50_DC_Tq = r(p50)

* ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* DEFINES NETWORK LEVEL VARS (median centrality of injection points)
bysort net50_ID: egen DC_t1_medi_temp= median(DC_t1_p1_rel1) if type==1
bysort net50_ID: egen DC_t1_medi=mean(DC_t1_medi_temp) if relevant_network==1

bysort net50_ID: egen DC_t10_medi_temp= median(DC_t10_p1_rel1) if type==1
bysort net50_ID: egen DC_t10_medi=mean(DC_t10_medi_temp) if relevant_network==1

bysort net50_ID: egen DC_Tq_medi_temp= median(DC_norm) if type==1
bysort net50_ID: egen DC_Tq_medi=mean(DC_Tq_medi_temp) if relevant_network==1

bysort net50_ID: egen EC_medi_temp= median(EV_centr) if type==1
bysort net50_ID: egen EC_medi=mean(EC_medi_temp) if relevant_network==1

drop EC_*_temp
drop DC_*_temp

* ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* Generating Rates for below/above Median

*DC high and low for T=1
foreach Y in all base threat {
  qui gen     DC_`Y'high_1 = 0
  qui replace DC_`Y'high_1=1 if field_`Y'1==1 & DC_t1_p1_rel1> p50_DC1_p1
  bys net50_ID: egen m_`Y'up_highDC_1=sum(DC_`Y'high_1)
	replace m_`Y'up_highDC_1=0 if m_`Y'up_highDC_1==.
	replace m_`Y'up_highDC_1=m_`Y'up_highDC_1/(net_N-1)
  }

foreach Y in all base threat {
  qui gen DC_`Y'low_1 = 0
  qui replace DC_`Y'low_1=1 if field_`Y'1==1 & DC_t1_p1_rel1<= p50_DC1_p1
  bys net50_ID: egen m_`Y'up_lowDC_1=sum(DC_`Y'low_1)
	replace m_`Y'up_lowDC_1=0 if m_`Y'up_lowDC_1==.
	replace m_`Y'up_lowDC_1=m_`Y'up_lowDC_1/(net_N-1)
  }

*DC high and low for T=10
  foreach Y in all base threat {
  qui gen     DC_`Y'high_10 = 0
  qui replace DC_`Y'high_10 = 1 if field_`Y'1==1 & DC_t10_p1_rel1> p50_DC10_p1
  bys net50_ID: egen m_`Y'up_highDC_10=sum(DC_`Y'high_10)
	replace m_`Y'up_highDC_10=0 if m_`Y'up_highDC_10==.
	replace m_`Y'up_highDC_10=m_`Y'up_highDC_10/(net_N-1)
  }

  foreach Y in all base threat {
  qui gen     DC_`Y'low_10 = 0
  qui replace DC_`Y'low_10 = 1 if field_`Y'1==1 & DC_t10_p1_rel1<= p50_DC10_p1
  bys net50_ID: egen m_`Y'up_lowDC_10=sum(DC_`Y'low_10)
	replace m_`Y'up_lowDC_10=0 if m_`Y'up_lowDC_10==.
	replace m_`Y'up_lowDC_10=m_`Y'up_lowDC_10/(net_N-1)
  }

*EV high and low
 foreach Y in all base threat {
  qui gen EV_`Y'high = 0
  qui replace EV_`Y'high=1 if field_`Y'1==1 & EV_centr> p50_EV
  bys net50_ID: egen m_`Y'up_highEV=sum(EV_`Y'high)
	replace m_`Y'up_highEV=0 if m_`Y'up_highEV==.
	replace m_`Y'up_highEV=m_`Y'up_highEV/(net_N-1)
  }

 foreach Y in all base threat {
  qui gen EV_`Y'low = 0
  qui replace EV_`Y'low=1 if field_`Y'1==1 & EV_centr<= p50_EV
  bys net50_ID: egen m_`Y'up_lowEV=sum(EV_`Y'low)
	replace m_`Y'up_lowEV=0 if m_`Y'up_lowEV==.
	replace m_`Y'up_lowEV=m_`Y'up_lowEV/(net_N-1)
  }


*DC_general high and low
foreach Y in all base threat {
  qui gen     DC_general_`Y'high = 0
  qui replace DC_general_`Y'high = 1 if field_`Y'1==1 & DC_norm > p50_DC_Tq
  bys net50_ID: egen m_`Y'up_highDC_Tq=sum(DC_general_`Y'high)
	replace m_`Y'up_highDC_Tq=0 if m_`Y'up_highDC_Tq==.
	replace m_`Y'up_highDC_Tq=m_`Y'up_highDC_Tq/(net_N-1)
  }

foreach Y in all base threat {
  qui gen     DC_general_`Y'low = 0
  qui replace DC_general_`Y'low = 1 if field_`Y'1==1 & DC_norm <= p50_DC_Tq
  bys net50_ID: egen m_`Y'up_lowDC_Tq=sum(DC_general_`Y'low)
	replace m_`Y'up_lowDC_Tq=0 if m_`Y'up_lowDC_Tq==.
	replace m_`Y'up_lowDC_Tq=m_`Y'up_lowDC_Tq/(net_N-1)
  }


*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

**********************
* TABLE 6  - Estimates
**********************

gen base_low  = m_baseup_lowDC_1
gen base_high = m_baseup_highDC_1
gen threat_low  = m_threatup_lowDC_1
gen threat_high = m_threatup_highDC_1
gen total_low  = m_allup_lowDC_1
gen total_high = m_allup_highDC_1

*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ col 1+2
*** DC1 - w/o Total_k
areg compliance base_low base_high threat_low threat_high  if  type==2, absorb(m_allup) cluster(net50_ID)
 test base_low = base_high
   local f1f=r(F)
 test threat_low = threat_high
   local f2f=r(F)
 outreg2 base_low base_high threat_low threat_high  using Table_6, tex(frag) nocons   adds(Networks, e(N_clust), BaseF, `f1f', ThreatF, `f2f') sdec(4) bdec(4) ctitle(DC1) replace


*** DC1 - w/ Total_k
reg compliance base_low base_high threat_low threat_high total_low total_high if  type==2,  cluster(net50_ID)
 test total_low + base_low = total_high + base_high
   local  f1f=r(F)
 test total_low + threat_low = total_high + threat_high
   local  f2f=r(F)
  outreg2 base_low base_high threat_low threat_high total_low total_high   using Table_6, tex(frag) nocons   adds(Networks, e(N_clust), BaseF, `f1f', ThreatF, `f2f') sdec(4) bdec(4) ctitle(DC1) append


*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ col 3+4
*** DC10 - w/o & w/ Total_k

replace base_low  = m_baseup_lowDC_10
replace base_high = m_baseup_highDC_10
replace threat_low  = m_threatup_lowDC_10
replace threat_high = m_threatup_highDC_10
replace total_low  = m_allup_lowDC_10
replace total_high = m_allup_highDC_10

areg compliance  base_low base_high threat_low threat_high    if  type==2, absorb(m_allup) cluster(net50_ID)
 test base_low = base_high
   local  f1f=r(F)
 test threat_low = threat_high
   local  f2f=r(F)
  outreg2 base_low base_high threat_low threat_high  using Table_6, tex(frag) nocons   adds(Networks, e(N_clust), BaseF, `f1f', ThreatF, `f2f') sdec(4) bdec(4) ctitle(DC10) append

reg compliance base_low base_high threat_low threat_high total_low total_high if  type==2,  cluster(net50_ID)
 test total_low + base_low = total_high + base_high
   local  f1f=r(F)
 test total_low + threat_low = total_high + threat_high
   local  f2f=r(F)
  outreg2 base_low base_high threat_low threat_high total_low total_high   using Table_6, tex(frag) nocons   adds(Networks, e(N_clust), BaseF, `f1f', ThreatF, `f2f') sdec(4) bdec(4) ctitle(DC10) append


*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ col 5+6
*** DC-qt - w/o & w/ Total_k

replace base_low  = m_baseup_lowDC_Tq
replace base_high = m_baseup_highDC_Tq
replace threat_low  = m_threatup_lowDC_Tq
replace threat_high = m_threatup_highDC_Tq
replace total_low  = m_allup_lowDC_Tq
replace total_high = m_allup_highDC_Tq

areg compliance  base_low base_high threat_low threat_high    if  type==2, absorb(m_allup) cluster(net50_ID)
 test base_low = base_high
   local  f1f=r(F)
 test threat_low = threat_high
   local  f2f=r(F)
  outreg2 base_low base_high threat_low threat_high  using Table_6, tex(frag) nocons   adds(Networks, e(N_clust), BaseF, `f1f', ThreatF, `f2f') sdec(4) bdec(4) ctitle(DC-qt) append

reg compliance base_low base_high threat_low threat_high total_low total_high if  type==2,  cluster(net50_ID)
 test total_low + base_low = total_high + base_high
   local  f1f=r(F)
 test total_low + threat_low = total_high + threat_high
   local  f2f=r(F)
  outreg2 base_low base_high threat_low threat_high total_low total_high   using Table_6, tex(frag) nocons   adds(Networks, e(N_clust), BaseF, `f1f', ThreatF, `f2f') sdec(4) bdec(4) ctitle(DC-qt) append


*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ col 7+8
*** EV - w/o & w/ Total_k

replace base_low  = m_baseup_lowEV
replace base_high = m_baseup_highEV
replace threat_low  = m_threatup_lowEV
replace threat_high = m_threatup_highEV
replace total_low  = m_allup_lowEV
replace total_high = m_allup_highEV

areg compliance  base_low base_high threat_low threat_high    if  type==2, absorb(m_allup) cluster(net50_ID)
 test base_low = base_high
   local  f1f=r(F)
 test threat_low = threat_high
   local  f2f=r(F)
  outreg2 base_low base_high threat_low threat_high  using Table_6, tex(frag) nocons   adds(Networks, e(N_clust), BaseF, `f1f', ThreatF, `f2f') sdec(4) bdec(4) ctitle(EV) append

reg compliance base_low base_high threat_low threat_high total_low total_high if  type==2,  cluster(net50_ID)
 test total_low + base_low = total_high + base_high
   local  f1f=r(F)
 test total_low + threat_low = total_high + threat_high
   local  f2f=r(F)
  outreg2 base_low base_high threat_low threat_high total_low total_high   using Table_6, tex(frag) nocons   adds(Networks, e(N_clust), BaseF, `f1f', ThreatF, `f2f') sdec(4) bdec(4) ctitle(EV) append



*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

**********************
* Table B7 - Robustness : controlling for median centrality
**********************

* ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*** DC1 - w/o Total_k

replace base_low  = m_baseup_lowDC_1
replace base_high = m_baseup_highDC_1
replace threat_low  = m_threatup_lowDC_1
replace threat_high = m_threatup_highDC_1
replace total_low  = m_allup_lowDC_1
replace total_high = m_allup_highDC_1

areg compliance base_low base_high threat_low threat_high                        DC_t1_medi if  type==2, absorb(m_allup) cluster(net50_ID)
 test base_low = base_high
   local f1f=r(F)
 test threat_low = threat_high
   local f2f=r(F)
 outreg2 base_low base_high threat_low threat_high  using "Table_B7.tex", tex(frag) nocons   adds(Networks, e(N_clust), BaseF, `f1f', ThreatF, `f2f') sdec(4) bdec(4) ctitle(DC1) replace

reg compliance base_low base_high threat_low threat_high total_low total_high    DC_t1_medi if  type==2,  cluster(net50_ID)
 test total_low + base_low = total_high + base_high
   local  f1f=r(F)
 test total_low + threat_low = total_high + threat_high
   local  f2f=r(F)
  outreg2 base_low base_high threat_low threat_high total_low total_high   using "Table_B7.tex", tex(frag) nocons   adds(Networks, e(N_clust), BaseF, `f1f', ThreatF, `f2f') sdec(4) bdec(4) ctitle(DC1) append

* ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*** DC10 - w/o & w/ Total_k

replace base_low  = m_baseup_lowDC_10
replace base_high = m_baseup_highDC_10
replace threat_low  = m_threatup_lowDC_10
replace threat_high = m_threatup_highDC_10
replace total_low  = m_allup_lowDC_10
replace total_high = m_allup_highDC_10

areg compliance base_low base_high threat_low threat_high                        DC_t10_medi if  type==2, absorb(m_allup) cluster(net50_ID)
 test base_low = base_high
   local f1f=r(F)
 test threat_low = threat_high
   local f2f=r(F)
 outreg2 base_low base_high threat_low threat_high  using "Table_B7.tex", tex(frag) nocons   adds(Networks, e(N_clust), BaseF, `f1f', ThreatF, `f2f') sdec(4) bdec(4) ctitle(DC10) append

reg compliance base_low base_high threat_low threat_high total_low total_high    DC_t10_medi if  type==2,  cluster(net50_ID)
 test total_low + base_low = total_high + base_high
   local  f1f=r(F)
 test total_low + threat_low = total_high + threat_high
   local  f2f=r(F)
  outreg2 base_low base_high threat_low threat_high total_low total_high   using "Table_B7.tex", tex(frag) nocons   adds(Networks, e(N_clust), BaseF, `f1f', ThreatF, `f2f') sdec(4) bdec(4) ctitle(DC10) append

* ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*** DC-Tq - w/o & w/ Total_k

replace base_low  = m_baseup_lowDC_Tq
replace base_high = m_baseup_highDC_Tq
replace threat_low  = m_threatup_lowDC_Tq
replace threat_high = m_threatup_highDC_Tq
replace total_low  = m_allup_lowDC_Tq
replace total_high = m_allup_highDC_Tq

areg compliance base_low base_high threat_low threat_high                        DC_Tq_medi if  type==2, absorb(m_allup) cluster(net50_ID)
 test base_low = base_high
   local f1f=r(F)
 test threat_low = threat_high
   local f2f=r(F)
 outreg2 base_low base_high threat_low threat_high  using "Table_B7.tex", tex(frag) nocons   adds(Networks, e(N_clust), BaseF, `f1f', ThreatF, `f2f') sdec(4) bdec(4) ctitle(DC-Tq) append

reg compliance base_low base_high threat_low threat_high total_low total_high    DC_Tq_medi if  type==2,  cluster(net50_ID)
 test total_low + base_low = total_high + base_high
   local  f1f=r(F)
 test total_low + threat_low = total_high + threat_high
   local  f2f=r(F)
  outreg2 base_low base_high threat_low threat_high total_low total_high   using "Table_B7.tex", tex(frag) nocons   adds(Networks, e(N_clust), BaseF, `f1f', ThreatF, `f2f') sdec(4) bdec(4) ctitle(DC-Tq) append

* ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*** EV - w/o & w/ Total_k

replace base_low  = m_baseup_lowEV
replace base_high = m_baseup_highEV
replace threat_low  = m_threatup_lowEV
replace threat_high = m_threatup_highEV
replace total_low  = m_allup_lowEV
replace total_high = m_allup_highEV

areg compliance base_low base_high threat_low threat_high                        EC_medi if  type==2, absorb(m_allup) cluster(net50_ID)
 test base_low = base_high
   local f1f=r(F)
 test threat_low = threat_high
   local f2f=r(F)
 outreg2 base_low base_high threat_low threat_high  using "Table_B7.tex", tex(frag) nocons   adds(Networks, e(N_clust), BaseF, `f1f', ThreatF, `f2f') sdec(4) bdec(4) ctitle(EV) append

reg compliance base_low base_high threat_low threat_high total_low total_high    EC_medi if  type==2,  cluster(net50_ID)
 test total_low + base_low = total_high + base_high
   local  f1f=r(F)
 test total_low + threat_low = total_high + threat_high
   local  f2f=r(F)
  outreg2 base_low base_high threat_low threat_high total_low total_high   using "Table_B7.tex", tex(frag) nocons   adds(Networks, e(N_clust), BaseF, `f1f', ThreatF, `f2f') sdec(4) bdec(4) ctitle(EV) append

* ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

* ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* Preparing for Table B6
* ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

* INTERACTION TERMS - part 1
sort net50_ID
*foreach X of varlist betweenness charpathl_new clustering degree  DC_norm EV_cent EV_cent_new1 EV_centr close_cent {
foreach X of varlist degree  DC_norm EV_centr  {
 foreach Y in all mail base threat {
  qui cap drop temp_inter
  qui gen temp_inter = `X'
  qui replace temp_inter = . if field_`Y'1==0
  bysort net50_ID: egen Inj_`X'_`Y' =mean(temp_inter)
  }
 }
*foreach X of varlist  betweenness charpathl_new clustering degree  DC_norm EV_cent EV_cent_new1 EV_centr close_cent {
foreach X of varlist degree  DC_norm EV_centr  {
 qui gen all_`X' = m_allup * Inj_`X'_all
 foreach Y in mail base threat {
  qui replace Inj_`X'_`Y' = 0 if Inj_`X'_`Y'==. & Inj_`X'_all~=.
  qui gen `Y'_`X' = m_`Y'up * Inj_`X'_`Y'
  }
 }
drop temp_inter

* INTERACTION TERMS - part 2 (DC with p=1 & p<1)
local R = 1
forvalues T = 1(9)10 {
*forvalues T = 1/10 {
 foreach P of numlist 1  {
* foreach P of numlist 1 25(25)75 33(33)66 {
  foreach Y in all mail base threat {
   qui cap drop temp_inter
   qui gen temp_inter = DC_t`T'_p`P'_rel`R'
   qui replace temp_inter = . if field_`Y'1==0
   bysort net50_ID: egen Inj_DC_t`T'_p`P'_rel`R'_`Y' =mean(temp_inter)
   }
  }
 }

local R = 1
forvalues T = 1(9)10 {
*forvalues T = 1/10 {
 foreach P of numlist 1  {
* foreach P of numlist 1 25(25)75 33(33)66 {
  qui gen all_DC_t`T'_p`P'_rel`R' = m_allup * Inj_DC_t`T'_p`P'_rel`R'_all
  foreach Y in mail base threat {
   qui replace Inj_DC_t`T'_p`P'_rel`R'_`Y' = 0 if Inj_DC_t`T'_p`P'_rel`R'_`Y'==. & Inj_DC_t`T'_p`P'_rel`R'_all~=.
   qui gen `Y'_DC_t`T'_p`P'_rel`R' = m_`Y'up * Inj_DC_t`T'_p`P'_rel`R'_`Y'
  }
 }
}
qui drop temp_inter


***********************
* TABLE B6 - Estimates
***********************

gen base_c=.
gen threat_c=.
gen Inj_base_c=.
gen Inj_threat_c=.
gen Inj_all_c=.

*~~~~~~~~~~~~~~~~~~~~~
*DC1 (col 1+2)
*~~~~~~~~~~~~~~~~~~~~~
foreach X of varlist DC_t1_p1_rel1   {
 replace base_c=        base_`X'
 replace threat_c=      threat_`X'
 replace Inj_base_c=    Inj_`X'_base
 replace Inj_threat_c=  Inj_`X'_threat
 replace Inj_all_c=     Inj_`X'_all
}

areg compliance    m_baseup m_threatup  base_c threat_c Inj_base_c Inj_threat_c                       if type==2, absorb(m_allup) cluster(net50_ID)
 test base_c= threat_c=0
 outreg2 m_baseup m_threatup  base_c threat_c Inj_base_c Inj_threat_c             using "Table_B6.tex", tex(frag) nocons addstat(TestF, `r(F)', Testp, `r(p)') sdec(4) bdec(4) ctitle(DC1) replace

areg compliance    m_baseup m_threatup  base_c threat_c Inj_base_c Inj_threat_c  Inj_all_c                    if type==2, absorb(m_allup) cluster(net50_ID)
 test base_c= threat_c=0
 outreg2 m_baseup m_threatup  base_c threat_c Inj_base_c Inj_threat_c  Inj_all_c  using "Table_B6.tex", tex(frag) nocons addstat(TestF, `r(F)', Testp, `r(p)') sdec(4) bdec(4) ctitle(DC1) append

*~~~~~~~~~~~~~~~~~~~~~
*DC10 (col 3+4)
*~~~~~~~~~~~~~~~~~~~~~
foreach X of varlist DC_t10_p1_rel1   {
 replace base_c=        base_`X'
 replace threat_c=      threat_`X'
 replace Inj_base_c=    Inj_`X'_base
 replace Inj_threat_c=  Inj_`X'_threat
 replace Inj_all_c=     Inj_`X'_all
}

areg compliance    m_baseup m_threatup  base_c threat_c Inj_base_c Inj_threat_c                      if type==2, absorb(m_allup) cluster(net50_ID)
 test base_c= threat_c=0
 outreg2 m_baseup m_threatup  base_c threat_c Inj_base_c Inj_threat_c            using "Table_B6.tex", tex(frag) nocons addstat(TestF, `r(F)', Testp, `r(p)') sdec(4) bdec(4) ctitle(DC10) append

areg compliance    m_baseup m_threatup  base_c threat_c Inj_base_c Inj_threat_c  Inj_all_c                    if type==2, absorb(m_allup) cluster(net50_ID)
 test base_c= threat_c=0
 outreg2 m_baseup m_threatup  base_c threat_c Inj_base_c Inj_threat_c  Inj_all_c  using "Table_B6.tex", tex(frag) nocons addstat(TestF, `r(F)', Testp, `r(p)') sdec(4) bdec(4) ctitle(DC10) append

*~~~~~~~~~~~~~~~~~~~~~
*DC-Tq (col 5+6)
*~~~~~~~~~~~~~~~~~~~~~
foreach X of varlist DC_norm   {
 replace base_c=        base_`X'
 replace threat_c=      threat_`X'
 replace Inj_base_c=    Inj_`X'_base
 replace Inj_threat_c=  Inj_`X'_threat
 replace Inj_all_c=     Inj_`X'_all
}

areg compliance    m_baseup m_threatup  base_c threat_c Inj_base_c Inj_threat_c                       if type==2, absorb(m_allup) cluster(net50_ID)
 test base_c= threat_c=0
 outreg2 m_baseup m_threatup  base_c threat_c Inj_base_c Inj_threat_c       using "Table_B6.tex", tex(frag) nocons addstat(TestF, `r(F)', Testp, `r(p)') sdec(4) bdec(4) ctitle(DC-Tq) append

areg compliance    m_baseup m_threatup  base_c threat_c Inj_base_c Inj_threat_c  Inj_all_c                    if type==2, absorb(m_allup) cluster(net50_ID)
 test base_c= threat_c=0
 outreg2 m_baseup m_threatup  base_c threat_c Inj_base_c Inj_threat_c  Inj_all_c  using "Table_B6.tex", tex(frag) nocons addstat(TestF, `r(F)', Testp, `r(p)') sdec(4) bdec(4) ctitle(DC-Tq) append

*~~~~~~~~~~~~~~~~~~~~~
* EC (col 7+8)
*~~~~~~~~~~~~~~~~~~~~~
foreach X of varlist EV_centr   {
 replace base_c=        base_`X'
 replace threat_c=      threat_`X'
 replace Inj_base_c=    Inj_`X'_base
 replace Inj_threat_c=  Inj_`X'_threat
 replace Inj_all_c=     Inj_`X'_all
}

areg compliance    m_baseup m_threatup  base_c threat_c Inj_base_c Inj_threat_c                            if type==2, absorb(m_allup) cluster(net50_ID)
 test base_c= threat_c=0
 outreg2 m_baseup m_threatup  base_c threat_c Inj_base_c Inj_threat_c          using "Table_B6.tex", tex(frag) nocons addstat(TestF, `r(F)', Testp, `r(p)') sdec(4) bdec(4) ctitle(EC) append

areg compliance    m_baseup m_threatup  base_c threat_c Inj_base_c Inj_threat_c  Inj_all_c                    if type==2, absorb(m_allup) cluster(net50_ID)
 test base_c= threat_c=0
 outreg2 m_baseup m_threatup  base_c threat_c Inj_base_c Inj_threat_c  Inj_all_c  using "Table_B6.tex", tex(frag) nocons addstat(TestF, `r(F)', Testp, `r(p)') sdec(4) bdec(4) ctitle(EC) append

* ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

****************
*TABLE B8  (robustness check of Tab6)
****************

cap drop base_low base_high threat_low threat_high total_low total_high

gen base_low  = .
gen base_high = .
gen threat_low  = .
gen threat_high = .
gen total_low  = .
gen total_high = .

*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* Part 1.) DIFFERNT T --- for p = 1.00
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

forvalues T = 1/10 {

 qui sum DC_t`T'_p1_rel1 if type==1,d
  scalar p50_DC`T'_p1 = r(p50)

 foreach Y in all base threat {

   qui gen     DC_`Y'high_`T'_1 = 0
   qui replace DC_`Y'high_`T'_1 = 1 if field_`Y'1==1 & DC_t`T'_p1_rel1> p50_DC`T'_p1
   bys net50_ID: egen m_`Y'up_highDC_`T'_1=sum(DC_`Y'high_`T'_1)
 	qui replace m_`Y'up_highDC_`T'_1 = 0                          if m_`Y'up_highDC_`T'_1==.
 	qui replace m_`Y'up_highDC_`T'_1 = m_`Y'up_highDC_`T'_1/(net_N-1)

   qui gen     DC_`Y'low_`T'_1 = 0
   qui replace DC_`Y'low_`T'_1 = 1 if field_`Y'1==1 & DC_t`T'_p1_rel1<= p50_DC`T'_p1
   bys net50_ID: egen m_`Y'up_lowDC_`T'_1=sum(DC_`Y'low_`T'_1)
 	qui replace m_`Y'up_lowDC_`T'_1 = 0                         if m_`Y'up_lowDC_`T'_1==.
 	qui replace m_`Y'up_lowDC_`T'_1 = m_`Y'up_lowDC_`T'_1/(net_N-1)

   }

 drop DC_*low_`T'_1 DC_*high_`T'_1

}

replace base_low  = m_baseup_lowDC_1_1
replace base_high = m_baseup_highDC_1_1
replace threat_low  = m_threatup_lowDC_1_1
replace threat_high = m_threatup_highDC_1_1
replace total_low  = m_allup_lowDC_1_1
replace total_high = m_allup_highDC_1_1

qui reg compliance base_low base_high threat_low threat_high total_low total_high   if  type==2,  cluster(net50_ID)
 qui  test total_low + base_low = total_high + base_high
   local f1f=r(F)
 qui  test total_low + threat_low = total_high + threat_high
   local f2f=r(F)
 qui outreg2 base_low base_high threat_low threat_high total_low total_high  using "Table_B8_q1.tex", tex(frag) nocons  adds(Networks, e(N_clust), BaseF, `f1f', ThreatF, `f2f') sdec(4) bdec(4) replace


forvalues T = 2/10 {

replace base_low  = m_baseup_lowDC_`T'_1
replace base_high = m_baseup_highDC_`T'_1
replace threat_low  = m_threatup_lowDC_`T'_1
replace threat_high = m_threatup_highDC_`T'_1
replace total_low  = m_allup_lowDC_`T'_1
replace total_high = m_allup_highDC_`T'_1

qui reg compliance base_low base_high threat_low threat_high total_low total_high   if  type==2,  cluster(net50_ID)
 qui  test total_low + base_low = total_high + base_high
   local f1f=r(F)
 qui  test total_low + threat_low = total_high + threat_high
   local f2f=r(F)
 qui outreg2 base_low base_high threat_low threat_high total_low total_high  using "Table_B8_q1.tex", tex(frag) nocons  adds(Networks, e(N_clust), BaseF, `f1f', ThreatF, `f2f') sdec(4) bdec(4) append

}

*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* Part 2.) DIFFERNT T --- loop over different p-values
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

foreach P of numlist 25(25)75           {

forvalues T = 1/10 {
 qui sum DC_t`T'_p`P'_rel1 if type==1,d
  scalar p50_DC`T'_p`P' = r(p50)

 foreach Y in all base threat {
   qui gen     DC_`Y'high_`T'_`P' = 0
   qui replace DC_`Y'high_`T'_`P' = 1 if field_`Y'1==1 & DC_t`T'_p`P'_rel1> p50_DC`T'_p`P'
   bys net50_ID: egen m_`Y'up_highDC_`T'_`P'=sum(DC_`Y'high_`T'_`P')
 	qui replace m_`Y'up_highDC_`T'_`P' = 0                          if m_`Y'up_highDC_`T'_`P'==.
 	qui replace m_`Y'up_highDC_`T'_`P' = m_`Y'up_highDC_`T'_`P'/(net_N-1)

   qui gen     DC_`Y'low_`T'_`P' = 0
   qui replace DC_`Y'low_`T'_`P' = 1 if field_`Y'1==1 & DC_t`T'_p`P'_rel1<= p50_DC`T'_p`P'
   bys net50_ID: egen m_`Y'up_lowDC_`T'_`P'=sum(DC_`Y'low_`T'_`P')
 	qui replace m_`Y'up_lowDC_`T'_`P' = 0                         if m_`Y'up_lowDC_`T'_`P'==.
 	qui replace m_`Y'up_lowDC_`T'_`P' = m_`Y'up_lowDC_`T'_`P'/(net_N-1)

   }

 drop DC_*low_`T'_`P' DC_*high_`T'_`P'

}

*~~~~~~~~~~~~~~~~~~~~~~~

 qui replace base_low  = m_baseup_lowDC_1_`P'
 qui replace base_high = m_baseup_highDC_1_`P'
 qui replace threat_low  = m_threatup_lowDC_1_`P'
 qui replace threat_high = m_threatup_highDC_1_`P'
 qui replace total_low  = m_allup_lowDC_1_`P'
 qui replace total_high = m_allup_highDC_1_`P'

 qui reg compliance base_low base_high threat_low threat_high total_low total_high   if type==2,  cluster(net50_ID)
  qui  test total_low + base_low = total_high + base_high
    local f1f=r(F)
  qui  test total_low + threat_low = total_high + threat_high
    local f2f=r(F)
  qui outreg2 base_low base_high threat_low threat_high total_low total_high  using Table_B8_q`P'.tex, tex(frag) nocons  adds(Networks, e(N_clust), BaseF, `f1f', ThreatF, `f2f') sdec(4) bdec(4) replace

 forvalues T = 2/10 {

   qui replace base_low  = m_baseup_lowDC_`T'_`P'
   qui replace base_high = m_baseup_highDC_`T'_`P'
   qui replace threat_low  = m_threatup_lowDC_`T'_`P'
   qui replace threat_high = m_threatup_highDC_`T'_`P'
   qui replace total_low  = m_allup_lowDC_`T'_`P'
   qui replace total_high = m_allup_highDC_`T'_`P'

   qui reg compliance base_low base_high threat_low threat_high total_low total_high   if  type==2,  cluster(net50_ID)
    qui  test total_low + base_low = total_high + base_high
      local f1f=r(F)
    qui  test total_low + threat_low = total_high + threat_high
      local f2f=r(F)
    qui outreg2 base_low base_high threat_low threat_high total_low total_high  using Table_B8_q`P'.tex, tex(frag) nocons  adds(Networks, e(N_clust), BaseF, `f1f', ThreatF, `f2f') sdec(4) bdec(4) append

 }

}

* ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

* ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*** Preparing for Table 7 Estimates
* ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

gen fon1threat=0
replace fon1threat=1 if fon_2==1 & field_threat1==1
gen fon1base=0
replace fon1base=1 if fon_1==1 & field_base1==1
gen fon1all=0
replace fon1all=1 if fon==1 & field_all1==1
gen fonmail=0
replace fonmail=1 if fon_1==1 & field_base1==1
replace fonmail=1 if fon_2==1 & field_threat1==1

bysort  net50_ID: egen LCS_threat=sum(fon1threat)
by      net50_ID: egen LCS_base=sum(fon1base)
by      net50_ID: egen LCS_all=sum(fon1all)
by      net50_ID: egen LCS_mail=sum(fonmail)

replace LCS_threat=LCS_threat/m_threat1
replace LCS_base=LCS_base/m_base1
replace LCS_all=LCS_all/m_all1
replace LCS_mail=LCS_mail/m_mail1

foreach x in base threat mail all {
 replace LCS_`x'=0 if LCS_`x'==.
 gen LCD_`x'=0
 replace LCD_`x'=1 if LCS_`x'>0
 gen m_`x'_LCS = LCS_`x'*m_`x'up
 replace m_`x'_LCS=0 if m_`x'_LCS==.
 gen m_`x'_LCD = LCD_`x'*m_`x'up
 replace m_`x'_LCD=0 if m_`x'_LCD==.
 }

*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* number of fons with given treatment
gen fon_base_counter =counter10_50 + counter11_50
gen fon_threat_counter=counter20_50 +counter21_50
gen fon_mail_counter=counter20_50 +counter21_50 + counter10_50 + counter11_50
rename counter_50 fon_all_counter

* sum of same-i-type links & sum-of all links (degree-sum) for i-types
foreach x in base threat mail all {

 qui replace fon_`x'_counter = 0         if field_`x'1 == 0
 qui gen injection_degree_`x'=degree if field_`x'1 == 1
 qui bysort net50_ID: egen s_`x'=sum(fon_`x'_counter)
 qui by     net50_ID: egen inj_`x'=sum(injection_degree_`x')

 qui gen H_`x'=s_`x'/inj_`x'
 qui replace H_`x'=0 if inj_`x'==0
 qui replace H_`x' = 0  if H_`x' == .
 qui gen w_`x' = m_`x'1/net_N
 qui gen IH_`x'=((H_`x'-w_`x')/(1-w_`x'))
 qui replace IH_`x'=0 if w_`x'==1
 qui gen      IH_neg_`x'=0
 qui replace  IH_neg_`x'=1 if IH_`x'<0
 qui gen      IH_pos_`x'=0
 qui replace  IH_pos_`x'=1 if IH_`x'>=0
 qui gen m_`x'_H    =m_`x'up     * H_`x'
 qui gen m_`x'_IH   =m_`x'up     * IH_`x'
 qui gen m_`x'_IH_neg=m_`x'up    * IH_neg_`x'
 qui gen m_`x'_IH_pos=m_`x'up    * IH_pos_`x'

}
qui drop injection_degree_*
qui drop fon_*_counter

**********************
*** TABLE 7 - Estimates
**********************
areg compliance  m_baseup m_threatup        m_base_IH m_threat_IH IH_threat IH_base           if type==2 , cluster(net50_ID)  absorb(m_allup)
  outreg2 using "Table_7.tex", tex(frag) nocons sdec(4) bdec(4) ctitle(IH) replace
areg compliance  m_baseup m_threatup        m_base_IH m_threat_IH IH_threat IH_base     IH_all      if type==2 , cluster(net50_ID)  absorb(m_allup)
  outreg2 using "Table_7.tex", tex(frag) nocons sdec(4) bdec(4) ctitle(IH) append
areg compliance  m_baseup m_threatup        m_base_IH_pos m_threat_IH_pos IH_pos_threat IH_pos_base           if type==2 , cluster(net50_ID)  absorb(m_allup)
  outreg2 using "Table_7.tex", tex(frag) nocons sdec(4) bdec(4) ctitle(IHD) append
areg compliance  m_baseup m_threatup        m_base_IH_pos m_threat_IH_pos IH_pos_threat IH_pos_base   IH_pos_all        if type==2 , cluster(net50_ID)  absorb(m_allup)
  outreg2 using "Table_7.tex", tex(frag) nocons sdec(4) bdec(4) ctitle(IHD) append

* ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


**********************
*** TABLE B9 - Robustness Check (compare Tab 7)
**********************

areg compliance  m_mailup   m_mail_H      H_mail                         if type==2 , cluster(net50_ID)  absorb(m_allup)
  outreg2 using "Table_B9.tex", tex(frag) nocons sdec(4) bdec(4) ctitle(IH) replace
areg compliance  m_mailup   m_mail_H      H_mail       H_all             if type==2 , cluster(net50_ID)  absorb(m_allup)
  outreg2 using "Table_B9.tex", tex(frag) nocons sdec(4) bdec(4) ctitle(IH) append
areg compliance  m_mailup   m_mail_IH_pos IH_pos_mail                    if type==2 , cluster(net50_ID)  absorb(m_allup)
  outreg2 using "Table_B9.tex", tex(frag) nocons sdec(4) bdec(4) ctitle(IHD) append
areg compliance  m_mailup   m_mail_IH_pos IH_pos_mail IH_pos_all         if type==2 , cluster(net50_ID)  absorb(m_allup)
  outreg2 using "Table_B9.tex", tex(frag) nocons sdec(4) bdec(4) ctitle(IHD) append


* ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

**********************
*** TABLE B2
**********************

cap bysort net50_ID: egen detection_rate=mean(detection_pre)


*************
*Tab B2 - COLUMNS 1 + 3
*************
preserve
keep if type==2
collapse       net_N clustering degree EV_centr detection_rate IH_all IH_pos_all Inj_DC_t1_p1_rel1_all Inj_DC_t10_p1_rel1_all Inj_EV_centr_all m_baseup m_threatup m_allup, by(net50_ID)
local append replace
local first 1
foreach var in net_N clustering degree EV_centr detection_rate Inj_DC_t1_p1_rel1_all Inj_DC_t10_p1_rel1_all Inj_EV_centr_all IH_all IH_pos_all  {
areg  m_baseup   `var'  , a(m_allup) cluster(net50_ID)
 outreg2 `var'  using "Table_B2_Col1", dec(4) addstat(Networks, e(N_clust)) nocons tex(nopretty)
areg  m_threatup   `var'  , a(m_allup) cluster(net50_ID)
 outreg2 `var'  using "Table_B2_Col3", dec(4) addstat(Networks, e(N_clust)) nocons tex(nopretty)
}
restore

*************
*Tab B2 - COLUMNS 2 + 4
*************
preserve
keep if type==2
collapse       pop2005 income  age_municip rel_kath nat_A    turnout home m_baseup m_allup m_threatup, by(municip)
cap gen nat_nonA=1-nat_A
foreach var in pop2005 income  age_municip rel_kath nat_nonA  home  turnout {
areg  m_baseup   `var'  , a(m_allup) cluster(municip)
 outreg2 `var'  using "Table_B2_Col2", dec(4) addstat(Networks, e(N_clust)) nocons tex(nopretty)
areg  m_threatup   `var'  , a(m_allup) cluster(municip)
 outreg2 `var'  using "Table_B2_Col4", dec(4) addstat(Networks, e(N_clust)) nocons tex(nopretty)
}
restore



* ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* F I G U R E S
* ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

*ssc install dsconcat
*scc install grstyle
grstyle init
grstyle color background white

/*

**********************
*** FIGURE 4
**********************
preserve

* ~~~~~~~~~~~~~~~~~~~~~~~~~~~
* Fig 4 - Part 1: Simulation
* ~~~~~~~~~~~~~~~~~~~~~~~~~~~

cap mkdir "placebo"

***keep all households from all MUNICIPALITIES that are covered by the main sample
bysort municip: egen relevant_municip=max(relevant_network)
keep if relevant_municip==1
count
drop relevant_municip

keep ID municip net50_ID compliance field_*1 m_all1 m_base1 m_threat1 detection_pre comp_exante type

compress
save "placebo\data_reg50_temp.dta", replace
clear

set seed 815

** s= number of households in a random-network
local s = 10
** max t = number of iterations
local t = 1
while `t' <= 1000 {
di `t'
cap clear
use "placebo\data_reg50_temp.dta"
bys municip: gen rannum = uniform()
by  municip: egen rank = rank(rannum)
qui gen fake=0
local i = 0
while `i' < 10000 {
qui bys municip: replace fake=`i'*municip*11777 if `i'==rank
local i = `i' + `s'
}

sort municip rank
local i = 1
while `i' < `s' {
qui bys municip: gen fake`i'=fake[_n+`i']
local i = `i' + 1
}
qui egen net50_IDfake`s'=rowmax(fake*)
bys municip: egen maxnet50_IDfake`s'=max(net50_IDfake`s')
by  municip: replace net50_IDfake`s'=maxnet50_IDfake`s' if net50_IDfake`s'==0

bys municip net50_IDfake`s': gen net_N`s'= _N

qui drop fake fake* rannum rank

bysort municip net50_IDfake`s': egen m_basefake`s'=sum(field_base1)
qui replace m_basefake`s'=m_basefake`s'-1 if field_base1==1
qui replace  m_basefake`s'=m_basefake`s'/(net_N`s'-1)

bysort municip net50_IDfake`s': egen m_threatfake`s'=sum(field_threat1)
qui replace m_threatfake`s'=m_threatfake`s'-1 if field_threat1==1
qui replace  m_threatfake`s'=m_threatfake`s'/(net_N`s'-1)

bysort municip net50_IDfake`s':  egen m_allfake`s'=sum(field_all1)
qui replace m_allfake`s'=m_allfake`s'-1 if field_all1==1
qui replace  m_allfake`s'=m_allfake`s'/(net_N`s'-1)

bysort ID:  egen m_allup`t'fake`s'=sum(m_allfake`s')
by ID: egen m_baseup`t'fake`s'=sum(m_basefake`s')
by ID: egen m_threatup`t'fake`s'=sum(m_threatfake`s')

qui rename net50_IDfake`s' net50_ID`t'fake`s'
qui drop m_basefake`s' m_threatfake`s'  m_allfake`s'
qui areg compliance  m_baseup`t'fake`s' m_threatup`t'fake`s'  if type == 2, absorb(m_allup`t'fake`s')  cluster(net50_ID`t'fake`s')
parmest, saving(placebo\param`t', replace)
local t = `t' + 1
}

di "ready"


* ~~~~~~~~~~~~~~~~~~~~~~~~~~~
* Fig 4 - Part 2: Figure
* ~~~~~~~~~~~~~~~~~~~~~~~~~~~

cap clear
use "placebo\param1.dta"
forvalues t = 2(1)1000 {
 append using "placebo\param`t'.dta"
}
compress
*gen     var=4 if parm=="_cons"
*replace var=3 if var[_n+1]==4
*replace var=2 if var[_n+2]==4
*replace var=1 if var[_n+3]==4
gen     var=3 if parm=="_cons"
replace var=2 if var[_n+1]==3
replace var=1 if var[_n+2]==3
compress
save "placebo\param_all.dta",replace

keep if var==1
su estimate,d
cumul estimate, gen(cdf_base)

twoway scatter cdf_base estimate, sort msymbol(Oh) xline(0.2431, lpattern(dash)) ylabel(0 "0" 0.2 "0.2" 0.4 "0.4" 0.6 "0.6" 0.8 "0.8" 1 "1", angle(horizontal)) xlabel(-0.40 "-0.40" -0.20 "-0.20" 0.00 "0.00" 0.20 "0.20" 0.40 "0.40", angle(horizontal)) ytitle("cumulative distribution function") xtitle("Coefficients on baseline mailing rate for randomly generated networks") text(0.2 0.06 " ")
graph export "Figure_4_base.pdf", as(pdf) replace
count if estimate>=0.2431

su dof,d
***************************
clear
use "placebo\param_all.dta"
keep if var==2
su estimate,d
cumul estimate, gen(cdf_threat)

twoway scatter cdf_threat estimate, sort xline(0.3496, lpattern(dash)) msymbol(Oh)  ylabel(0 "0" 0.2 "0.2" 0.4 "0.4" 0.6 "0.6" 0.8 "0.8" 1 "1", angle(horizontal)) xlabel(-0.40 "-0.40" -0.20 "-0.20" 0.00 "0.00" 0.20 "0.20" 0.40 "0.40", angle(horizontal)) ytitle("cumulative distribution function") xtitle("Coefficients on threat mailing rate for randomly generated networks") text(0.2 0.06 " ")
graph export "Figure_4_threat.pdf", as(pdf) replace
count if estimate>=0.3496

su dof,d

clear

restore

*/


**********************
*** FIGURE B.1
**********************
preserve

keep if relevant_network==1

*gen temp_threat=m_allup
*gen temp_base  =m_allup
*gen temp_cont  =m_allup
*label variable temp_threat "Threat Mail"
*label variable temp_base   "Baseline Mail"
*label variable temp_cont   "Control (No Mail)"
*graph twoway kdensity temp_threat if  field_threat1==1, lpattern(longdash) || kdensity temp_base if  field_base1==1 || kdensity temp_cont if  field_nomail1==1,  lpattern(shortdash) xtitle("Rate of experimental Households (Total_k)") ytitle("Density")  bw(0.05) legend(position(7) row(1) region(lwidth(none)))


grstyle graphsize x 6
grstyle graphsize y 4

*graph twoway kdensity m_allup if  field_threat1==1 || kdensity m_allup if  field_base1==1 || kdensity m_allup if  field_nomail1==1, xtitle("Rate of experimental Households (Total_k)") ytitle("Density")  bw(0.05)
*graph twoway kdensity m_allup if  field_threat1==1, lpattern(longdash) || kdensity m_allup if  field_base1==1 || kdensity m_allup if  field_nomail1==1,  lpattern(shortdash) xtitle("Rate of experimental Households (Total_k)") ytitle("Density")  bw(0.05)
*graph twoway kdensity m_allup if  field_base1==1 || kdensity m_allup if  field_threat1==1, lpattern(longdash) || kdensity m_allup if  field_nomail1==1,  lpattern(shortdash) xtitle("Rate of experimental Households (Total_k)") ytitle("Density")  bw(0.05) legend(label(1 "Baseline Mail") label(2 "Threat Mail") label(3 "Control (No Mail)")) position(7) row(1) region(lwidth(none)))
graph twoway kdensity m_allup if  field_base1==1 || kdensity m_allup if  field_threat1==1, lpattern(longdash) || kdensity m_allup if  field_nomail1==1,  lpattern(shortdash) xtitle("Rate of experimental Households (Total_k)") ytitle("Density")   legend(label(1 "Baseline Mail") label(2 "Threat Mail") label(3 "Control (No Mail)") position(7) row(1) region(lwidth(none))) saving("Figure_B1.gph", replace)
graph export "Figure_B1.pdf", as(pdf)  replace

restore

log close
