*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* PAPER: Compliance Behavior in Networks: Evidence from a Field Experiment
* AUTHORS: Francesco Drago, Friederike Mengel, & Christian Traxler
* JOURNAL: AEJ: Applied Econ
*
* Replication File #2 (Table 4 + Input for Table B1)
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

clear all
version 13
set more off

* !!! ADJUST YOUR DIRECTORY HERE !!!
global folder "C:\DATA\networks\"
cd    "$folder"

cap mkdir OUTPUT
cap log close
log using "OUTPUT\replication_part02.log",replace

*z = distance defining the network (<=> dta file)
local z = 25
use "Networks_`z'.dta"

*******************************************
* INPUT FOR TABLE B1
*******************************************

gen type=.
label var type "types (in relevant networks only)"

*** Type II Houeholds : conditions (1) NOT part of field experiment, (2) initially non-compliant, (3) in a network with at least one experimental (type I) households
replace type=2 if field_all1==0 & comp_exante==0 & m_all1>0

* Temporary indicator: networks w at least one type II households
bysort net`z'_ID: egen type2_in=max(type)

*** Type I HHs
replace type=1 if field_all1==1 & m_all1>0 & type2_in==2

*** Type III
*not included in these data!

* ~~~~~~~~~~~~~~~~~~~~~~
* Indicator for relevant_networks
gen      relevant_network=0
replace  relevant_network=1 if type2_in==2 & m_all1>0

preserve
keep if  relevant_network==1
sort net`z'_ID
drop if net`z'_ID==net`z'_ID[_n-1]
count
su net_N
restore

*******************************************
* TABLE 4 (Baseline Regression for z = 25; followed by alterantive weighting of coefficients)
*******************************************
reg compliance  m_baseup m_threatup  m_allup if type == 2 , cluster(net`z'_ID)
 gen     temp2=1 if e(sample)
 loc b0=_b[m_allup]
 loc b1=_b[m_baseup]
 loc b2=_b[m_threatup]
*
sort temp2 net`z'_ID ID
 replace temp2=. if net`z'_ID==net`z'_ID[_n-1]
* Unweighted average of net_N
 qui su net_N if temp2==1,d
 local mean=r(mean)
*
 scalar base_mean= (`b0'+`b1')/(`mean'-1)
 scalar threat_mean= (`b0'+`b2')/(`mean'-1)
*
 scalar base_mean_1= (1000/e(N_clust))*((`b0'+`b1')/(`mean'-1))
 scalar threat_mean_1= (1000/e(N_clust))*((`b0'+`b2')/(`mean'-1))
*
 scalar base_mean_2=  e(N)*base_mean_1
 scalar threat_mean_2=  e(N)*threat_mean_1
*
 outreg2 m_allup m_baseup m_threatup  using "OUTPUT/Table_4.xls",  dec(4) addstat(Number of Networks, e(N_clust), ///
         Base_mean, base_mean, Threat_mean, threat_mean, ///
         All_Base, base_mean_2, All_Threat, threat_mean_2) ctitle ("`z'")  label replace
 scalar drop _all

clear


* ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

cap clear
use  "Networks_50.dta"

local z = 50

gen type=.
label var type "types (in relevant networks only)"
*** Type II Houeholds : conditions (1) NOT part of field experiment, (2) initially non-compliant, (3) in a network with at least one experimental (type I) households
replace type=2 if field_all1==0 & comp_exante==0 & m_all1>0

*=> input for Table B1 is in replication file #1

*******************************************
* TABLE 4 (Baseline Regression for z = 50)
*******************************************
reg compliance  m_baseup m_threatup  m_allup if type == 2 , cluster(net50_ID)
 gen     temp2=1 if e(sample)
 loc b0=_b[m_allup]
 loc b1=_b[m_baseup]
 loc b2=_b[m_threatup]
*
sort temp2 net50_ID ID
 replace temp2=. if net50_ID==net50_ID[_n-1]
* Unweighted average of net_N
 qui su net_N if temp2==1,d
 local mean=r(mean)
*
 scalar base_mean= (`b0'+`b1')/(`mean'-1)
 scalar threat_mean= (`b0'+`b2')/(`mean'-1)
*
 scalar base_mean_1= (1000/e(N_clust))*((`b0'+`b1')/(`mean'-1))
 scalar threat_mean_1= (1000/e(N_clust))*((`b0'+`b2')/(`mean'-1))
*
 scalar base_mean_2=  e(N)*base_mean_1
 scalar threat_mean_2=  e(N)*threat_mean_1
*
 outreg2 m_allup m_baseup m_threatup  using "OUTPUT/Table_4.xls",  dec(4)  addstat(Number of Networks, e(N_clust), ///
         Base_mean, base_mean, Threat_mean, threat_mean, ///
         All_Base, base_mean_2, All_Threat, threat_mean_2) ctitle ("50")  label append
 scalar drop _all

clear


*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* Loop over different network assumptions z, replicating steps from above (for z = 25)
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

foreach z in 75 100 250 500 1000 1500 2000 {
 cap clear
 use Networks_`z'.dta
* ~~~~~~~~~~~~~~~~~~~~~~
* ~~~~~~~~~~~~~~~~~~~~~~
 di "NETWORKS FOR Z ="
 di `z'
* ~~~~~~~~~~~~~~~~~~~~~~
* ~~~~~~~~~~~~~~~~~~~~~~
 gen type=.
 replace type=2 if field_all1==0 & comp_exante==0 & m_all1>0
 bysort net`z'_ID: egen type2_in=max(type)
 replace type=1 if field_all1==1 & m_all1>0 & type2_in==2
 tab type
* ~~~~~~~~~~~~~~~~~~~~~~
 gen      relevant_network=0
 replace  relevant_network=1 if type2_in==2 & m_all1>0
* ~~~~~~~~~~~~~~~~~~~~~~
 preserve
 keep if  relevant_network==1
 sort net`z'_ID
 drop if net`z'_ID==net`z'_ID[_n-1]
 count
 su net_N
 restore
* ~~~~~~~~~~~~~~~~~~~~~~
*estimates
reg compliance  m_baseup m_threatup  m_allup if type==2, cluster(net`z'_ID)
 gen     temp2=1 if e(sample)
 qui count if temp2==1
 local sample_N=r(N)
 loc b0=_b[m_allup]
 loc b1=_b[m_baseup]
 loc b2=_b[m_threatup]
*
sort temp2 net`z'_ID ID
 replace temp2=. if net`z'_ID==net`z'_ID[_n-1]
* Unweighted average of net_N
 qui su net_N if temp2==1,d
 local mean=r(mean)
*
 scalar base_mean= (`b0'+`b1')/(`mean'-1)
 scalar threat_mean= (`b0'+`b2')/(`mean'-1)
*
 scalar base_mean_1= (1000/e(N_clust))*((`b0'+`b1')/(`mean'-1))
 scalar threat_mean_1= (1000/e(N_clust))*((`b0'+`b2')/(`mean'-1))
*
 scalar base_mean_2=  e(N)*base_mean_1
 scalar threat_mean_2=  e(N)*threat_mean_1
*
 outreg2 m_allup m_baseup m_threatup  using "OUTPUT/Table_4.xls",  dec(4)  addstat(Number of Networks, e(N_clust), ///
         Base_mean, base_mean, Threat_mean, threat_mean, ///
         All_Base, base_mean_2, All_Threat, threat_mean_2) ctitle (`z')  label append
 scalar drop _all
}


log close
