*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* PAPER: Compliance Behavior in Networks: Evidence from a Field Experiment
* AUTHORS: Francesco Drago, Friederike Mengel, & Christian Traxler
* JOURNAL: AEJ: Applied Econ
*
* Replication File #3 (Online-Survey/Section II; => FIG 1 &   TAB/FIGs from Appendix A)
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

*ssc install statsmat
*ssc install outtable

clear all
version 13
set more off

* !!! ADJUST YOUR DIRECTORY HERE !!!
global folder "C:\DATA\networks\"
cd    "$folder"

cap clear
use "Networks_Survey.dta", clear
cap mkdir OUTPUT

cap log close
log using "OUTPUT\replication_part03.log",replace

* ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

gen     n1_conv=nb1_conv_freq
replace n1_conv=app_nb0_conv_freq if n1_conv==.
gen     n2_conv=nb2_conv_freq
replace n2_conv=app_nb1_conv_freq if n2_conv==.
gen     n3_conv=nb3_conv_freq
replace n3_conv=app_nb2_conv_freq if n3_conv==.

gen     n1_dist=nb1_dist
replace n1_dist=1 if nb1_dist==.
gen     n2_dist=nb2_dist
replace n2_dist=app_nb1_dist if nb2_dist==.
gen     n3_dist=nb3_dist
replace n3_dist=app_nb2_dist if nb3_dist==.

gen     n1_know=nb1_knowl
replace n1_know=app_nb0_knowl if n1_know==.
gen     n2_know=nb2_knowl
replace n2_know=app_nb1_knowl if n2_know==.
gen     n3_know=nb3_knowl
replace n3_know=app_nb2_knowl if n3_know==.

gen     n1_friend=nb1_friend
replace n1_friend=app_nb0_friend if n1_friend==.
gen     n2_friend=nb2_friend
replace n2_friend=app_nb1_friend if n2_friend==.
gen     n3_friend=nb3_friend
replace n3_friend=app_nb2_friend if n3_friend==.

label value n1_conv   lb_convfreq
label value n1_know   lb_knowl
label value n1_friend lb_friend
label value n2_conv   lb_convfreq
label value n2_know   lb_knowl
label value n2_friend lb_friend
label value n3_conv   lb_convfreq
label value n3_know   lb_knowl
label value n3_friend lb_friend
label value n1_dist lb_nbdist
label value n2_dist lb_nbdist
label value n3_dist lb_nbdist

gen edu_years=.
replace edu_years=9 if education==5
replace edu_years=10 if education==4
replace edu_years=11 if education==3
replace edu_years=12 if education==2
replace edu_years=15 if education==1

gen working=0
replace working=1 if employment==2
gen unem=0
replace unem=1 if employment==5

* ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* RESULTS
* ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~


**********************
** Table A1 (Sumstats)
**********************

gen     family_house=0
replace family_house=1 if housing==1
gen     small_municip=0
replace small_municip=1 if quota==1
gen     occ_school= 0
replace occ_school=1 if employ==1
gen     occ_work= 0
replace occ_work=1 if employ==2
gen     occ_retired= 0
replace occ_retired=1 if employ==3

gen     edu_low=0
replace edu_low=1 if (education==4|education==5)
gen     edu_high=0
replace edu_high=1 if (education==1)

gen fem=1-male

statsmat age fem edu_h edu_l occ_w occ_s occ_r family_house small_municip , s(mean sd) m(sumstat)

matrix table1 = sumstat
matname table1 mean sd, columns(.) explicit
matname table1 Age Female Education-High Education-Low Occ-Working Occ-School Occ-Retired 1Family-Housing Small-Municip, rows(.) explicit
outtable using "OUTPUT\Table_A1", mat(table1) replace nobox caption(Summary Statistics) center clabel(Tab:SumStat) asis format(%9.2f)
matrix list table1


* ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

preserve

expand 3
sort id_survey
gen neighb=1
replace neighb=2 if id_survey==id_survey[_n-1] & id_survey~=id_survey[_n-2]
replace neighb=3 if id_survey==id_survey[_n-1] & id_survey==id_survey[_n-2] & id_survey~=id_survey[_n-3]

label define lb_neighb 1 "1st neighbor" 2 "2nd neighbor" 3 "3rd neighbor"
label value neighb lb_neighb

gen     n_conv=.
gen     n_know=.
forval i = 1/3 {
 replace n_conv=n`i'_conv if neighb==`i'
 replace n_know=n`i'_know if neighb==`i'
}

gen     n_conv_h1=0
replace n_conv_h1=1 if n_conv==1
label var n_conv_h1 "very frequently"
gen     n_conv_h2=0
replace n_conv_h2=1 if n_conv==2
label var n_conv_h2 "frequently"

gen     n_conv_vhigh=0
replace n_conv_vhigh=1 if n_conv==1
gen     n_conv_high=0
replace n_conv_high=1 if n_conv<=2

gen     n_conv_friend_vhigh=0
replace n_conv_friend_vhigh=1 if friend_conv_freq==1
gen     n_conv_friend_high=0
replace n_conv_friend_high=1 if friend_conv_freq<=2

gen     n_conv_friend_h1=0
replace n_conv_friend_h1=1 if friend_conv_freq==1
gen     n_conv_friend_h2=0
replace n_conv_friend_h2=1 if friend_conv_freq==2

recode n_conv (2 1 = 1) (3 = 2) (4 5 = 3)
recode n_know (2 1 = 1) (3 = 2) (4 5 = 3)

*** ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*** FIGURE A1 : 1st - 2nd - 3rd neighbor : communication frequencies
*** ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

graph bar n_conv_h2 n_conv_h1 , by(neighb, note("") row(1) title(, size(medium) color(black))) stack bar(1, fcolor(eltblue) fintensity(inten100) lcolor(black)) bar(2, fcolor(maroon) fintensity(inten100) lcolor(black)) ytitle(Fraction indicating high communication frequency , size(small)) ylabel(0.00(0.1)0.55, labsize(small) angle(horizontal)) by(, graphregion(margin(tiny))) xsize(7) ysize(6) legend(order(2 "Very frequent communication" 1 "Frequent communication") rows(2) region(lcolor(white)) size(medsmall))
 graph export "OUTPUT\Figure_A1.pdf", as(pdf) font(Arial) replace

tab n_conv_high neighb,col
tab n_conv_h1 neighb,col
tab n_conv_h2 neighb,col


*** ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*** communication frequencies by distance (for 1st - 2nd - 3rd neighbor)
*** ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

label define lb_nbdist_4 2 "0 - 50m" 3 "50 - 100m" 4 "100 - 200m" 5 "200 -500m" 6 "> 500m"

forval i = 1/3 {
 qui gen     n`i'_dist_4=n`i'_dist
 qui replace n`i'_dist_4=2 if n`i'_dist==1
 qui label value n`i'_dist_4 lb_nbdist_4
}

label define lb_nbdist_2 2 "0 - 50m" 3 "50 - 100m" 4 "100 - 200m" 5 "> 200m"
forval i = 1/3 {
 qui gen n`i'_dist_2=n`i'_dist_4
 qui replace n`i'_dist_2=5 if n`i'_dist_4==6
 qui label value n`i'_dist_2 lb_nbdist_2
}

label define lb_nbdist_3   1 "< 25m" 2 "25 - 50m" 3 "50 - 100m" 4 "100 - 200m" 5 "> 200m"
forval i = 1/3 {
 qui gen n`i'_dist_3=n`i'_dist
 qui replace n`i'_dist_3=5 if n`i'_dist==6
 qui label value n`i'_dist_3 lb_nbdist_3
}

* ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*** FIGURE A2 : communication with 1st neighbor by distance
* ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

graph bar n_conv_h2 n_conv_h1 if neighb==1                 , by(n1_dist_4, note("") row(1) title(, size(medium) color(black))) stack bar(1, fcolor(eltblue) fintensity(inten100) lcolor(black)) bar(2, fcolor(maroon) fintensity(inten100) lcolor(black)) ytitle(Fraction indicating high communication frequency , size(small)) ylabel(0.00(0.1)0.62, labsize(small) angle(horizontal)) by(, graphregion(margin(tiny))) xsize(7.5) ysize(6) legend(order(2 "Very frequent comm." 1 "Frequent communication") rows(1) region(lcolor(white)) size(medsmall))
 graph export "OUTPUT\Figure_A2.pdf", as(pdf) font(Arial) replace

tab n_conv_high n1_dist_4 if neighb==1,col
tab n_conv_h1 n1_dist_4 if neighb==1,col
tab n_conv_h2 n1_dist_4 if neighb==1,col


* ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*** FIGURE 1 (combining A1 + A2)
* ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

graph bar n_conv_h2 n_conv_h1 , by(neighb, note("") row(1)  title("(a) by network distance", size(medium) color(black))) fxsize(75) saving("OUTPUT/figure_1pt1_GRCtitle.gph", replace) stack bar(1, fcolor(eltblue) fintensity(inten100) lcolor(black) ) bar(2, fcolor(maroon) fintensity(inten100) lcolor(black)) ytitle(Fraction indicating high communication frequency , size(small)) ylabel(0.00(0.1)0.55, labsize(small) angle(horizontal)) by(, graphregion(margin(tiny))) xsize(7) ysize(6) legend(order(2 "Very frequent communication" 1 "Frequent communication") rows(1) region(lcolor(white)) size(medsmall))
graph bar n_conv_h2 n_conv_h1 if neighb==1, by(n1_dist_4, note("") row(1) title("(b) by geo-distance (for 1st order neighbor)", size(medium) color(black))) fxsize(110) saving("OUTPUT/figure_1pt2_GRCtitle.gph", replace) stack bar(1, fcolor(eltblue) fintensity(inten100) lcolor(black)) bar(2, fcolor(maroon) fintensity(inten100) lcolor(black)) ytitle(Fraction indicating high communication frequency , size(small)) ylabel(0.00(0.1)0.62, labsize(small) angle(horizontal)) by(, graphregion(margin(tiny)))  xsize(15) ysize(6) legend(order(2 "Very frequent communication" 1 "Frequent communication") rows(1) region(lcolor(white)) size(medsmall))

grc1leg2 "OUTPUT/figure_1pt1_GRCtitle.gph" "OUTPUT/figure_1pt2_GRCtitle.gph",  ///
col(2) graphregion(margin(large)) imargin(10 5) iscale(0.6) xcomm title("") graphregion(fcolor(white)) saving("OUTPUT/Figure_1.gph", replace) ysize(2) xsize(4)

* => final layout of figure 1 was manually adjusted.


* ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*** FIGURE A3: Distance and Housing Structure
* ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

gen     n_dist_house=  n1_dist if housing==1
replace n_dist_house=5+n1_dist if housing==3
replace n_dist_house=. if (n1_dist==3|n1_dist==4|n1_dist==5)
label define lb_nbdist88   1 "1fam-house & < 25m" 2 "1fam-house & 25-50m"  6 "apartment build. & < 25m"
label value n_dist_house lb_nbdist88

** Note: quota==1  is anlaogous to "population<=4" (<= 5000 inhab.)
graph bar n_conv_h2 n_conv_h1 if neighb==1 & quota==1               , by(n_dist_house, style(default) note("") col(2) title("(b) Small Muncipalities", size(medium) color(black))) stack bar(1, fcolor(eltblue) fintensity(inten100) lcolor(black)) bar(2, fcolor(maroon) fintensity(inten100) lcolor(black)) ytitle(Fraction indicating high communication frequency , size(small)) ylabel(0.00(0.1)0.6, labsize(small) angle(horizontal)) by(, graphregion(margin(tiny))) xsize(4) ysize(6) legend(order(1 "Frequent communication") rows(1) region(lcolor(white)) size(medium))
 graph export "OUTPUT\Figure_A3_b.pdf", as(pdf) font(Arial) replace

** Note: quota==2  is anlaogous to "population>4" (> 5000 inhab.)
graph bar n_conv_h2 n_conv_h1 if neighb==1 & quota==2               , by(n_dist_house, style(default) note("") col(2) title("(a) Large Muncipalities", size(medium) color(black))) stack bar(1, fcolor(eltblue) fintensity(inten100) lcolor(black)) bar(2, fcolor(maroon) fintensity(inten100) lcolor(black)) ytitle(Fraction indicating high communication frequency , size(small)) ylabel(0.00(0.1)0.6, labsize(small) angle(horizontal)) by(, graphregion(margin(tiny))) xsize(4) ysize(6) legend(order(2 "Very frequent communication") rows(1) region(lcolor(white)) size(medium))
 graph export "OUTPUT\Figure_A3_a.pdf", as(pdf) font(Arial) replace

*High OR Very High COMMUNICATION
tab n_conv_high n_dist_house if neighb==1 & quota==1,col
*VERY FREQUENT COMMUNICATION
tab n_conv_h1 n_dist_house if neighb==1 & quota==1,col
*FREQUENT COMMUNICATION
tab n_conv_h2 n_dist_house if neighb==1 & quota==1,col

tab n_conv_high n_dist_house if neighb==1 & quota==2,col
tab n_conv_h1 n_dist_house if neighb==1 & quota==2,col
tab n_conv_h2 n_dist_house if neighb==1 & quota==2,col


*** ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*** FIGURE A4: Benchmark: Communication w/ "best friend"
*** ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

recode friend_conv_freq (2 1 = 1) (3 = 2) (4 5 = 3)
gen     n_conv_ref=n_conv             if neighb==1 & friend_conv_freq~=.
replace n_conv_ref=friend_conv_freq   if neighb==2
gen friend=neighb if neighb<3
label define lb_friend2 1 "1st neighbor" 2 "best friend at work/school"
label value friend lb_friend2

gen     n_conv_ref2=n_conv_vhigh          if neighb==1 & friend_conv_freq~=.
replace n_conv_ref2=n_conv_friend_vhigh   if neighb==2
gen     n_conv_ref3=n_conv_high          if neighb==1 & friend_conv_freq~=.
replace n_conv_ref3=n_conv_friend_high   if neighb==2

gen     n_conv_ref4=n_conv_h1          if neighb==1 & friend_conv_freq~=.
replace n_conv_ref4=n_conv_friend_h1   if neighb==2
gen     n_conv_ref5=n_conv_h2          if neighb==1 & friend_conv_freq~=.
replace n_conv_ref5=n_conv_friend_h2   if neighb==2

* ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

graph bar n_conv_ref5 n_conv_ref4 if friend_conv_freq~=., by(friend, note("") row(1) title(, size(medium) color(black))) stack bar(1, fcolor(eltblue) fintensity(inten100) lcolor(black)) bar(2, fcolor(maroon) fintensity(inten100) lcolor(black)) ytitle("Fraction indicating high communication frequency", size(small)) ylabel(0.00(0.1)0.90, labsize(small) angle(horizontal)) by(, graphregion(margin(tiny))) xsize(6) ysize(6) legend(order(2 "Very frequent communication" 1 "Frequent communication") rows(2) region(lcolor(white)) size(medsmall))
 graph export "OUTPUT\Figure_A4.pdf", as(pdf) font(Arial) replace

*Frequent OR Very Frequent Communication
tab n_conv_ref3 friend if friend_conv_freq~=., col
*Frequent Communication
tab n_conv_ref5 friend if friend_conv_freq~=., col
*VERY Frequent Communication
tab n_conv_ref4 friend if friend_conv_freq~=., col


*** ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*** FIGURE A5: TOPICS OF COMMUNICATION
*** ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

restore
preserve

expand 4
sort id_survey
gen neighb=1
replace neighb=2 if id_survey==id_survey[_n-1] & id_survey~=id_survey[_n-2]
replace neighb=3 if id_survey==id_survey[_n-1] & id_survey==id_survey[_n-2] & id_survey~=id_survey[_n-3]
replace neighb=4 if id_survey==id_survey[_n-1] & id_survey==id_survey[_n-2] & id_survey==id_survey[_n-3] & id_survey~=id_survey[_n-4]

gen     nb_topics=nb_conv_freq_ins if neighb==1
replace nb_topics=nb_conv_freq_fina if neighb==2
replace nb_topics=nb_conv_freq_tvl  if neighb==3
replace nb_topics=nb_conv_freq_tax  if neighb==4
*
gen     nb_topics_vfreq=0
replace nb_topics_vfreq=1 if nb_topics==1
gen     nb_topics_freq=0
replace nb_topics_freq=1 if nb_topics==2
gen     nb_topics_hi=0
replace nb_topics_hi=1 if nb_topics<=2
*
recode  nb_topics (1 2 = 1) (3 = 2) (4 5 = 3)

rename neighb topic
label define lb_topic 1 "speed limit" 2 "jobs/financial" 3 "TV license fees" 4 "taxation"
label value topic lb_topic

graph bar nb_topics_freq  nb_topics_vfreq , by(topic, note("") row(1) title(, size(medium) color(black))) stack bar(1, fcolor(bluishgray) fintensity(inten100) lcolor(black)) bar(2, fcolor(dknavy) fintensity(inten100) lcolor(black)) ytitle(Share indicating frequent coverage of topic, size(small)) ylabel(0.00(0.05)0.3, labsize(small) angle(horizontal)) by(, graphregion(margin(tiny))) xsize(7.5) ysize(6) legend(order(2 "Very frequently discussed" 1 "Frequently discussed") rows(1) region(lcolor(white)) size(medsmall))
 graph export "OUTPUT\Figure_A5.pdf", as(pdf) font(Arial) replace

tab nb_topics_vfreq topic,col
tab nb_topics_freq topic,col
tab nb_topics_hi topic,col


*** ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*** FIGURE A6: Passing on Information
*** ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

gen     warning=warning_sp if topic==1
replace warning=warning_tv if topic==3

gen     warn_dyes=0 if topic==1
replace warn_dyes=1 if warning_sp==1 & topic==1
replace warn_dyes=0 if topic==3
replace warn_dyes=1 if warning_tv==1 & topic==3

gen     warn_yes=0 if topic==1
replace warn_yes=1 if warning_sp==2 & topic==1
replace warn_yes=0 if topic==3
replace warn_yes=1 if warning_tv==2 & topic==3

gen     warn_all=0 if topic==1
replace warn_all=1 if warning_sp<=2 & topic==1
replace warn_all=0 if topic==3
replace warn_all=1 if warning_tv<=2 & topic==3

drop if topic==2|topic==4

graph bar warn_yes  warn_dyes , by(topic, note("") row(1) title(, size(medium) color(black))) stack bar(1, fcolor(bluishgray) fintensity(inten100) lcolor(black)) bar(2, fcolor(dknavy) fintensity(inten100) lcolor(black)) ytitle("Fraction willing to warn neighbors", size(small)) ylabel(0.00(0.1)0.8, labsize(small) angle(horizontal)) by(, graphregion(margin(tiny))) xsize(6) ysize(5.5) legend(order(2 "Definitively yes" 1 "Yes") rows(1) region(lcolor(white)) size(medsmall))
 graph export "OUTPUT\Figure_A6.pdf", as(pdf) font(Arial) replace

tab warn_dyes topic,col
tab warn_yes topic,col
tab warn_all topic,col



log close
